@@ -2,7 +2,7 @@
 Types for sunbeam scripts
 """
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 from dataclasses import dataclass, asdict, field
 from typing import Literal
@@ -20,10 +20,13 @@ class ListItemDetail:
 @dataclass
 class Page:
     def json(self):
+        return json.dumps(self.dict())
+
+    def dict(self):
         def dict_factory(fields):
             return {field[0]: field[1] for field in fields if field[1]}
 
-        return json.dumps(asdict(self, dict_factory=dict_factory))
+        return asdict(self, dict_factory=dict_factory)
 
 
 @dataclass
